@@ -31,16 +31,25 @@ GulkanFrameBuffer *gulkan_frame_buffer_new (void);
 bool
 gulkan_frame_buffer_initialize (GulkanFrameBuffer    *self,
                                 GulkanDevice         *device,
-                                VkCommandBuffer       cmd_buffer,
                                 uint32_t              width,
                                 uint32_t              height,
                                 VkSampleCountFlagBits sample_count,
                                 VkFormat              color_format);
 
+bool
+gulkan_frame_buffer_initialize_from_image (GulkanFrameBuffer    *self,
+                                           GulkanDevice         *device,
+                                           VkImage               color_image,
+                                           uint32_t              width,
+                                           uint32_t              height,
+                                           VkSampleCountFlagBits sample_count,
+                                           VkFormat              color_format);
+
 void
 gulkan_frame_buffer_begin_pass (GulkanFrameBuffer *self,
                                 VkCommandBuffer    cmd_buffer);
 
+
 VkImage
 gulkan_frame_buffer_get_color_image (GulkanFrameBuffer *self);
 
